AuthSession

Struct AuthSession 

pub struct AuthSession<Backend>
where Backend: AuthnBackend,
{ pub user: Option<<Backend as AuthnBackend>::User>, pub backend: Backend, pub session: Session, /* private fields */ }
A specialized session for identification, authentication, and authorization of users associated with a backend.

The session is generic over some backend which implements AuthnBackend. The backend may also implement AuthzBackend, in which case it will also supply authorization methods.

Methods for authenticating the session and logging a user in are provided.

Generally this session will be used in the context of some authentication workflow, for example via a frontend login form. There a user would provide their credentials, such as username and password, and via the backend the session would authenticate those credentials.

Once the supplied credentials have been authenticated, a user will be returned. In the case the credentials are invalid, no user will be returned. When we do have a user, it’s then possible to set the state of the session so that the user is logged in.

Fields

user: Option<<Backend as AuthnBackend>::User>

The user associated by the backend. None when not logged in.

backend: Backend

The authentication and authorization backend.

session: Session

The underlying session.

Implementations

Source

impl<Backend> AuthSession<Backend>
where Backend: AuthnBackend,

pub async fn authenticate( &self, creds: <Backend as AuthnBackend>::Credentials, ) -> Result<Option<<Backend as AuthnBackend>::User>, Error<Backend>>

Verifies the provided credentials via the backend returning the authenticated user if valid and otherwise None.

pub async fn login( &mut self, user: &<Backend as AuthnBackend>::User, ) -> Result<(), Error<Backend>>

Updates the session such that the user is logged in.

pub async fn logout( &mut self, ) -> Result<Option<<Backend as AuthnBackend>::User>, Error<Backend>>

Updates the session such that the user is logged out.