SessionManagerLayer

Struct SessionManagerLayer 

pub struct SessionManagerLayer<Store, C = PlaintextCookie>
where Store: SessionStore, C: CookieController,
{ /* private fields */ }
A layer for providing Session as a request extension.

Implementations

Source

impl<Store, C> SessionManagerLayer<Store, C>
where Store: SessionStore, C: CookieController,

pub fn with_name<N>(self, name: N) -> SessionManagerLayer<Store, C>
where N: Into<Cow<'static, str>>,

Configures the name of the cookie used for the session. The default value is "id".

Examples
use tower_sessions::{MemoryStore, SessionManagerLayer};

let session_store = MemoryStore::default();
let session_service = SessionManagerLayer::new(session_store).with_name("my.sid");
pub fn with_http_only(self, http_only: bool) -> SessionManagerLayer<Store, C>

Configures the "HttpOnly" attribute of the cookie used for the session.

⚠️ Warning: Cross-site scripting risk

Applications should generally not override the default value of true. If you do, you are exposing your application to increased risk of cookie theft via techniques like cross-site scripting.

Examples
use tower_sessions::{MemoryStore, SessionManagerLayer};

let session_store = MemoryStore::default();
let session_service = SessionManagerLayer::new(session_store).with_http_only(true);
pub fn with_same_site( self, same_site: SameSite, ) -> SessionManagerLayer<Store, C>

Configures the "SameSite" attribute of the cookie used for the session. The default value is SameSite::Strict.

Examples
use tower_sessions::{cookie::SameSite, MemoryStore, SessionManagerLayer};

let session_store = MemoryStore::default();
let session_service = SessionManagerLayer::new(session_store).with_same_site(SameSite::Lax);
pub fn with_expiry(self, expiry: Expiry) -> SessionManagerLayer<Store, C>

Configures the "Max-Age" attribute of the cookie used for the session. The default value is None.

Examples
use time::Duration;
use tower_sessions::{Expiry, MemoryStore, SessionManagerLayer};

let session_store = MemoryStore::default();
let session_expiry = Expiry::OnInactivity(Duration::hours(1));
let session_service = SessionManagerLayer::new(session_store).with_expiry(session_expiry);
pub fn with_secure(self, secure: bool) -> SessionManagerLayer<Store, C>

Configures the "Secure" attribute of the cookie used for the session. The default value is true.

Examples
use tower_sessions::{MemoryStore, SessionManagerLayer};

let session_store = MemoryStore::default();
let session_service = SessionManagerLayer::new(session_store).with_secure(true);
pub fn with_path<P>(self, path: P) -> SessionManagerLayer<Store, C>
where P: Into<Cow<'static, str>>,

Configures the "Path" attribute of the cookie used for the session. The default value is "/".

Examples
use tower_sessions::{MemoryStore, SessionManagerLayer};

let session_store = MemoryStore::default();
let session_service = SessionManagerLayer::new(session_store).with_path("/some/path");
pub fn with_domain<D>(self, domain: D) -> SessionManagerLayer<Store, C>
where D: Into<Cow<'static, str>>,

Configures the "Domain" attribute of the cookie used for the session. The default value is None.

Examples
use tower_sessions::{MemoryStore, SessionManagerLayer};

let session_store = MemoryStore::default();
let session_service = SessionManagerLayer::new(session_store).with_domain("localhost");
pub fn with_always_save( self, always_save: bool, ) -> SessionManagerLayer<Store, C>

Configures whether unmodified session should be saved on read or not. When the value is true, the session will be saved even if it was not changed.

This is useful when you want to reset Session expiration time on any valid request at the cost of higher SessionStore write activity and transmitting set-cookie header with each response.

It makes sense to use this setting with relative session expiration values, such as Expiry::OnInactivity(Duration). This setting will not cause session id to be cycled on save.

The default value is false.

Examples
use time::Duration;
use tower_sessions::{Expiry, MemoryStore, SessionManagerLayer};

let session_store = MemoryStore::default();
let session_expiry = Expiry::OnInactivity(Duration::hours(1));
let session_service = SessionManagerLayer::new(session_store)
    .with_expiry(session_expiry)
    .with_always_save(true);
Source

impl<Store> SessionManagerLayer<Store>
where Store: SessionStore,

pub fn new(session_store: Store) -> SessionManagerLayer<Store>

Create a new SessionManagerLayer with the provided session store and default cookie configuration.

Examples
use tower_sessions::{MemoryStore, SessionManagerLayer};

let session_store = MemoryStore::default();
let session_service = SessionManagerLayer::new(session_store);